<?php
// $Id: linkintel.admin.inc,v 1.1 2010/10/21 20:29:29 tomdude48 Exp $

/**
 * @file
 * Admin include file.
 */

/**
 * Displays the form for the standard settings tab.
 *
 * @return
 *   array A structured array for use with Forms API.
 */
function linkintel_admin_settings() {
 

  $form['vocab'] = array(
    '#type' => 'fieldset',
    '#title' => t('Link request sync'),
    '#description' => t('You can automatically generate link requests using a vocabulary and page keywords from !kwresearch_link. Use the settings below to configure sync sources.',
      array(
        '!kwresearch_link' => l(t('Keyword Research'), 'http://drupal.org/project/kwresearch', array('attributes' => array('target', 'drupal'))),
      )
    ),
  );
  $vocabs = taxonomy_get_vocabularies();
  $options = array(0 => t('None'));
  foreach ($vocabs AS $vid => $v) {
    if ($v->tags) {
      $options[$vid] = $v->name;
    }
  }  
  $form['vocab']['linkintel_keyword_sync_vocabulary'] = array(    
    '#type' => 'select',    
    '#title' => t('Sync vocabulary'),   
    '#options' => $options,
    '#default_value' => variable_get('linkintel_keyword_sync_vocabulary', 0),     
    '#description' => t('Select a vocabulary to sync requests.')     
  ); 
  
  if(module_exists('kwresearch')) {
    $form['vocab']['linkintel_keyword_sync_kwresearch'] = array(    
      '#type' => 'checkbox',
      '#title' => t('Sync Keyword Research page keywords'), 
      '#return_value' => 1,
      '#default_value' => variable_get('linkintel_keyword_sync_kwresearch', 1),
      '#description' => t('Check if you want requests to be automatically synced with Keyword Research\'s page keywords.'),   
    );     
  }
  else {
    $form['vocab']['linkintel_keyword_sync_kwresearch'] = array(    
      '#type' => 'markup',
      '#value' => t('You can use the Keyword Research module as a source to auto-sync your link requests however it is not installed. !kwresearch_link',
        array(
          '!kwresearch_link' => l(t('Download Keyword Research module'), 'http://drupal.org/project/kwresearch', array('attributes' => array('target', 'drupal'))),
        )
      ),
    );    
  }
  
  $form['seeding'] = array(
    '#type' => 'fieldset',
    '#title' => t('Link suggestions keyword seeding'),
    '#description' => t('These settings enable you to seed keywords for a node on the link suggestions form.')
  );
  $form['seeding']['linkintel_suggestions_seed_vocabulary'] = array(    
    '#type' => 'select',    
    '#title' => t('Seed vocabulary'),   
    '#options' => $options,
    '#default_value' => variable_get('linkintel_suggestions_seed_vocabulary', 0),     
    '#description' => t('Select the vocabulary to gather terms for seeding.')     
  );
  if(module_exists('alchemy')) {
    
    $form['seeding']['alchemy'] = array(
      '#type' => 'fieldset',
      '#title' => t('Alchemy'),
      '#description' => t('Settings for using Alchemy keyword extraction to seed suggestions.')
    );
    
    $form['seeding']['alchemy']['linkintel_suggestions_seed_alchemy_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable Alchemy as a seed source'), 
      '#return_value' => 1,
      '#default_value' => variable_get('linkintel_suggestions_seed_alchemy_enabled', 1),
    );
    
    $options =alchemy_get_types();
    $form['seeding']['alchemy']['linkintel_suggestions_seed_alchemy_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Default data types'), 
      '#options' => $options,
      '#default_value' => variable_get('linkintel_suggestions_seed_alchemy_types', alchemy_get_types(TRUE)),
      '#description' => t('Alchemy provides an array of data it can extract from content. Use the above checkboxes to select which ones you want the content analyzer to perform by default.'),
    );
    
    $form['seeding']['alchemy']['linkintel_suggestions_seed_alchemy_threshold'] = array(
      '#type' => 'textfield',
      '#title' => t('Relevancy threshold'),
      '#default_value' => variable_get('linkintel_suggestions_seed_alchemy_threshold', 50),
      '#description' => t('Use this to specify the minimum relevance a phrase must have in order to be included. Set between 0 - 100.'),
      '#field_suffix' => t('%'),
      '#size' => 3,
    );
    
    $form['seeding']['alchemy']['linkintel_suggestions_seed_alchemy_usecache'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use cached data if available.'), 
      '#default_value' => variable_get('linkintel_suggestions_seed_alchemy_usecache', ''),
      '#description' => t('The responses from Alchemy are cached. If you want to enable fetching data from cache rather than fetching from the Alchemy API, check the above box.'),
      '#prefix' => '<div id="alchemy_contentanalysis_cache">',
      '#suffix' => '</div>',  
    );
  } 
  $form['autogen_params'] = array(
    '#type' => 'fieldset',
    '#title' => t('Autogen config'),
    '#description' => t('These settings allow you to tune the auto generated (autogen) link scoring.')
  );  
  $form['autogen_params']['linkintel_autogen_params_random'] = array(
    '#type' => 'textfield',
    '#title' => t('Randomness'),
    '#default_value' => variable_get('linkintel_autogen_params_random', 0),
    '#description' => t('Enables randomness in link selection. Set between 0 - 100. 0 will produce no randomness, 100 is completely random.'),
    //'#field_suffix' => t('%'),
    '#size' => 3,
  );  
 
  return system_settings_form($form);
}